% generate a fuzzy model for a SISO static function

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define constants
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Par.c = 5;          	% number of clusters
Par.m =  2;         	% fuzziness parameter
Par.tol = 0.01;         % termination criterion
Par.ante = 2;           % type of antecedent:   1 - product-space MFS
                        %                       2 - projected MFS
      

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% make data for the new syntax
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
u = (0:0.02:1)';
y = sin(7*u);
Dat.U = u;
Dat.Y = y;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% generate a fuzzy model by means of fuzzy clustering
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[FM,f] = fmclust(Dat,Par);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% simulate the fuzzy model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1); clf
[ym,VAF,dof,yl,ylm] = fmsim(u,y,FM);
title('Original function (blue) and fuzzy model (magenta)');
ylabel('Output');
disp('Hit any key to plot the membership functions and the corresponding local models ...'); pause

figure(1); clf
subplot(211); plot(u,ylm,u,y);
title('Original function (yellow) and local models');
xlabel('Input'); ylabel('Output');
subplot(212); plot(u,f)
title('Membership functions');
xlabel('Input'); ylabel('Membership grade');
VAF
disp('Hit any key to finish ...'); pause
close(1); clc;
